==> haskell-transformers-compat-0.7.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 transformers-compat
version:              0.7.2
visibility:           public
id:                   transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
key:                  transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/transformers-compat/
synopsis:             A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.

    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.

    Note: missing methods are not supplied, but this at least permits the types to be used.

category:             Compatibility
abi:                  46c4c3cbb981f27b4c25f727df1ad650
exposed:              True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal

hidden-modules:       Paths_transformers_compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/transformers-compat-0.7.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/transformers-compat-0.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-transformers-compat
hs-libraries:         HStransformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
depends:              base-4.16.4.0 ghc-prim-0.8.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock

haddock-html:         /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-compat-0.7.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 transformers-compat
version:              0.7.2
visibility:           public
id:                   transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
key:                  transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/transformers-compat/
synopsis:             A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.

    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.

    Note: missing methods are not supplied, but this at least permits the types to be used.

category:             Compatibility
abi:                  4afaf80d376d2551ab4581441199f6cb
exposed:              True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal

hidden-modules:       Paths_transformers_compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/transformers-compat-0.7.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/transformers-compat-0.7.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/transformers-compat-0.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-transformers-compat
hs-libraries:         HStransformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
depends:              base-4.17.2.1 ghc-prim-0.9.1 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock

haddock-html:         /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
